@@ -38,7 +38,7 @@ class IacScan:
         )
 
         findings_list, path_file_results = [], None
-        if skip_tool == "false":
+        if skip_tool is False:
             findings_list, path_file_results = self.tool_gateway.run_tool(
                 config_tool_iac,
                 folders_to_scan,
@@ -82,7 +82,7 @@ class IacScan:
 
     def complete_config_tool(self, data_file_tool, exclusions, tool, dict_args):
         config_tool = ConfigTool(json_data=data_file_tool)
-        skip_tool = "false"
+        skip_tool = False
 
         config_tool.exclusions = exclusions
         config_tool.scope_pipeline = self.devops_platform_gateway.get_variable(
@@ -95,13 +95,9 @@ class IacScan:
             config_tool.exclusions_scope = config_tool.exclusions.get(
                 config_tool.scope_pipeline
             ).get(tool)
-            skip_tool = (
-                "true"
-                if config_tool.exclusions.get(config_tool.scope_pipeline).get(
-                    "SKIP_TOOL"
-                )
-                else "false"
-            )
+            skip_tool = bool(config_tool.exclusions.get(config_tool.scope_pipeline).get("SKIP_TOOL"))
+        
+        skip_tool = bool(re.match(config_tool.ignore_search_pattern, config_tool.scope_pipeline, re.IGNORECASE))
 
         if dict_args["folder_path"]:
             if (
@@ -117,9 +113,7 @@ class IacScan:
 
             folders_to_scan = [dict_args["folder_path"]]
         else:
-            folders_to_scan = self.search_folders(
-                config_tool.search_pattern, config_tool.ignore_search_pattern
-            )
+            folders_to_scan = self.search_folders(config_tool.search_pattern)
 
         if len(folders_to_scan) == 0:
             logger.warning(
@@ -129,12 +123,10 @@ class IacScan:
 
         return config_tool, folders_to_scan, skip_tool
 
-    def search_folders(self, search_pattern, ignore_pattern):
+    def search_folders(self, search_pattern):
         current_directory = os.getcwd()
         patron = (
-            "(?i)(?!.*(?:"
-            + "|".join(ignore_pattern)
-            + ")).*?("
+            "(?i).*?("
             + "|".join(search_pattern)
             + ").*$"
         )
